VecDeque1

Type Alias VecDeque1 

pub type VecDeque1<T> = NonEmpty<VecDeque<T>>;
Available on crate feature alloc only.

Aliased Type

pub struct VecDeque1<T> { /* private fields */ }

Implementations

Source

impl<T> VecDeque1<T>

pub unsafe fn from_vec_deque_unchecked(items: VecDeque<T>) -> Self

Safety

items must be non-empty. For example, it is unsound to call this function with the immediate output of VecDeque::new().

pub fn from_one(item: T) -> Self

pub fn from_one_with_capacity(item: T, capacity: usize) -> Self

pub fn from_iter1_with_capacity<U>(items: U, capacity: usize) -> Self
where U: IntoIterator1<Item = T>,

pub fn from_head_and_tail<I>(head: T, tail: I) -> Self
where I: IntoIterator<Item = T>,

pub fn from_rtail_and_head<I>(tail: I, head: T) -> Self
where I: IntoIterator<Item = T>,

pub fn try_from_ref( items: &VecDeque<T>, ) -> Result<&Self, EmptyError<&VecDeque<T>>>

pub fn try_from_mut( items: &mut VecDeque<T>, ) -> Result<&mut Self, EmptyError<&mut VecDeque<T>>>

pub fn into_vec_deque(self) -> VecDeque<T>

pub fn try_retain<F>(self, f: F) -> Result<Self, EmptyError<VecDeque<T>>>
where F: FnMut(&T) -> bool,

pub fn retain_until_only<F>(&mut self, f: F) -> Option<&T>
where F: FnMut(&T) -> bool,

pub fn shrink_to(&mut self, capacity: usize)

pub fn shrink_to_fit(&mut self)

pub fn make_contiguous(&mut self) -> &mut Slice1<T>

pub fn rotate_left(&mut self, n: usize)

pub fn rotate_right(&mut self, n: usize)

pub fn split_off_tail(&mut self) -> VecDeque<T>

pub fn append(&mut self, items: &mut VecDeque<T>)

pub fn push_front(&mut self, item: T)

pub fn push_back(&mut self, item: T)

pub fn pop_front_if_many(&mut self) -> PopIfMany<'_, Self>

pub fn pop_back_if_many(&mut self) -> PopIfMany<'_, Self>

pub fn insert(&mut self, index: usize, item: T)

pub fn remove_if_many(&mut self, index: usize) -> RemoveIfMany<'_, Self>

pub fn swap_remove_front_if_many( &mut self, index: usize, ) -> RemoveIfMany<'_, Self>

pub fn swap_remove_back_if_many( &mut self, index: usize, ) -> RemoveIfMany<'_, Self>

pub fn get(&self, index: usize) -> Option<&T>

pub fn get_mut(&mut self, index: usize) -> Option<&mut T>

pub fn len(&self) -> NonZeroUsize

pub fn capacity(&self) -> NonZeroUsize

pub fn front(&self) -> &T

pub fn front_mut(&mut self) -> &mut T

pub fn back(&self) -> &T

pub fn back_mut(&mut self) -> &mut T

pub fn iter1(&self) -> Iterator1<Iter<'_, T>>

pub fn iter1_mut(&mut self) -> Iterator1<IterMut<'_, T>>

pub const fn as_vec_deque(&self) -> &VecDeque<T>

pub const unsafe fn as_mut_vec_deque(&mut self) -> &mut VecDeque<T>

Safety

The VecDeque behind the returned mutable reference must not be empty when the reference is dropped. Consider the following example:

use mitsein::vec_deque1::VecDeque1;

let mut xs = VecDeque1::from([0i32, 1, 2, 3]);
// This block is unsound. The `&mut VecDeque<_>` is dropped in the block and so `xs` can be
// freely manipulated after the block despite violation of the non-empty guarantee.
unsafe {
    xs.as_mut_vec_deque().clear();
}
let x = xs.front(); // Undefined behavior!
Source

impl<T> VecDeque1<T>

pub fn par_iter1( &self, ) -> ParallelIterator1<<&Self as IntoParallelIterator>::Iter>
where T: Sync,

Available on crate feature rayon only.
pub fn par_iter1_mut( &mut self, ) -> ParallelIterator1<<&mut Self as IntoParallelIterator>::Iter>
where T: Send,

Available on crate feature rayon only.